library(ggplot2)
library(data.table)
library(stargazer)
library(xtable)


ihs <- function(x) {
  y <- log(x + sqrt(x ^ 2 + 1))
  return(y)
}
hs <- function(x) {
  y <- 0.5*exp(-x)*(exp(2*x)-1)
  return(y)
}


dat <- fread("dyad_data.csv")
m1 <- lfe::felm(log_count ~ fenced +
                  ihs_stock + 
                  ihs(gdp_ratio) +
                  gdp_ratio2 +
                  contig.x +
                  comlang_off +
                  col45 + 
                  log(distw) +
                  lib_dem_o +
                  lib_dem +
                  ihs(pop_o) +
                  ihs(pop_d) +
                  nAC +
                  nCIV_o +
                  nINT + 
                  nINT_o |
                  iso3_o + iso3_d + year | 0 | dyad, data = dat)

m2 <- lfe::felm(log_count ~ fenced * policy5ma +
                  ihs_stock + 
                  ihs(gdp_ratio) +
                  gdp_ratio2 +
                  contig.x +
                  comlang_off +
                  col45 + 
                  log(distw) +
                  lib_dem_o +
                  lib_dem +
                  ihs(pop_o) +
                  ihs(pop_d) +
                  nAC +
                  nCIV_o +
                  nINT + 
                  nINT_o |
                  iso3_o + iso3_d + year | 0 | dyad, data = dat)


beta.hat <- coef(m2)
vcov1 <- vcov(m2)
z0 <- seq(min(dat$policy5ma, na.rm = TRUE), max(dat$policy5ma, na.rm = TRUE), length.out = 1000)
dy.dx <- beta.hat["fenced"] + beta.hat["fenced:policy5ma"]*z0
se.dy.dx <- sqrt(vcov1["fenced", "fenced"] + 
  (z0^2)*vcov1["fenced:policy5ma", "fenced:policy5ma"] + 2*z0*vcov1["fenced", "fenced:policy5ma"])
upr <- dy.dx + 1.96*se.dy.dx
lwr <- dy.dx - 1.96*se.dy.dx

# figure D.1(a)
png("figD1a.png", res = 300, 
    width = 6, height = 4, units = "in")
ggplot(data=NULL, aes(x=z0, y=dy.dx)) +
  labs(x="Policy liberality Index (5-year MA)", y="Marginal Effects",
       cex=4) +
  geom_line(aes(z0, dy.dx),size = 1) +
  geom_line(aes(z0, lwr), size = 1, linetype = 2, color="black") +
  geom_line(aes(z0, upr), size = 1, linetype = 2, color="black") +
  geom_hline(yintercept=0, size = 1, linetype=3) +
  geom_ribbon(aes(ymin=lwr, ymax=upr), alpha=0.3) +
  theme_bw()
dev.off()


# Table D.VI
m3 <- lfe::felm(log_count ~ fenced +
                  ihs_stock + 
                  ihs(gdp_ratio) +
                  gdp_ratio2 +
                  #contig.x +
                  comlang_off +
                  col45 + 
                  log(distw) +
                  lib_dem_o +
                  lib_dem +
                  ihs(pop_o) +
                  ihs(pop_d) +
                  nAC +
                  nCIV_o +
                  nINT + 
                  nINT_o |
                  iso3_o + iso3_d + year | 0 | dyad, data = dat[contig.x == 1])

stargazer(m3, type = "latex",
          omit = c("factor", "time_trend"),
          align = TRUE,
          star.cutoffs = c(.1, .05, .01),
          star.char = c("†", "*", "**"),
          dep.var.labels = "IHS Refugee Flow",
          covariate.labels = c("Border Fence", 
                               "Policy Liberality Index (5-year MA)",
                               "IHS Migrant Stock",
                               "IHS GDPc Ratio",
                               "IHS GDPc Ratio (sq)",
                             #  "Contiguous",
                               "Common Language",
                               "Colonial Tie",
                               "IHS Distance",
                               "Lib. Democracy Origin",
                               "Lib. Democracy Dest.",
                               "IHS Population Origin",
                               "IHS Population Dest.",
                               "Near Violence Dest.",
                               "Civil War Origin",
                               "International War Dest.",
                               "International War Origin.",
                               "Fence X Policy Liberality Index (5-year MA)"),
          add.lines = list(c("Origin FE", "$\\checkmark$"),
                           c("Dest. FE", "$\\checkmark$"),
                           c("Year FE", "$\\checkmark$")))


demig_dat <- fread("demig_dat.csv")

m4 <- lfe::felm(log_count ~ fenced * liberal_5yma +
                  ihs_stock + 
                  ihs(gdp_ratio) +
                  gdp_ratio2 +
                  contig.x +
                  comlang_off +
                  col45 + 
                  log(distw) +
                  lib_dem_o +
                  lib_dem +
                  ihs(pop_o) +
                  ihs(pop_d) +
                  nAC +
                  nCIV_o +
                  nINT + 
                  nINT_o |
                  iso3_o + iso3_d + year | 0 | dyad, data = demig_dat)

beta.hat <- coef(m4)
vcov1 <- vcov(m4)
z0 <- seq(min(demig_dat$liberal_5yma, na.rm = TRUE), 
          max(demig_dat$liberal_5yma, na.rm = TRUE), 
          length.out = 1000)
dy.dx <- beta.hat["fenced"] + beta.hat["fenced:liberal_5yma"]*z0
se.dy.dx <- sqrt(vcov1["fenced", "fenced"] + 
                   (z0^2)*vcov1["fenced:liberal_5yma", "fenced:liberal_5yma"] + 
                   2*z0*vcov1["fenced", "fenced:liberal_5yma"])
upr <- dy.dx + 1.96*se.dy.dx
lwr <- dy.dx - 1.96*se.dy.dx

# figure D.1(b)
png("figD1b.png", res = 300, 
    width = 6, height = 4, units = "in")
ggplot(data=NULL, aes(x=z0, y=dy.dx)) +
  labs(x="DEMIG Policy liberality Index (5-year MA)", y="Marginal Effects",
       cex=4) +
  geom_line(aes(z0, dy.dx),size = 1) +
  geom_line(aes(z0, lwr), size = 1, linetype = 2, color="black") +
  geom_line(aes(z0, upr), size = 1, linetype = 2, color="black") +
  geom_hline(yintercept=0, size = 1, linetype=3) +
  geom_ribbon(aes(ymin=lwr, ymax=upr), alpha=0.3) +
  theme_bw()
dev.off()

# table D.V
stargazer(m1, m2, m4, type = "latex",
          omit = c("factor", "time_trend"),
          align = TRUE,
          star.cutoffs = c(.1, .05, .01),
          star.char = c("†", "*", "**"),
          dep.var.labels = "IHS Refugee Flow",
          covariate.labels = c("Border Fence",
                               "Policy Liberality Index (5-year MA)",
                               "DEMIG Policy Liberality (5-year MA)",
                               "IHS Migrant Stock",
                               "IHS GDPc Ratio",
                               "IHS GDPc Ratio (sq)",
                               "Contiguous",
                               "Common Language",
                               "Colonial Tie",
                               "IHS Distance",
                               "Lib. Democracy Origin",
                               "Lib. Democracy Dest.",
                               "IHS Population Origin",
                               "IHS Population Dest.",
                               "Near Violence Dest.",
                               "Civil War Origin",
                               "International War Dest.",
                               "International War Origin.",
                               "Fence X Policy Liberality Index (5-year MA)",
                               "Fence X DEMIG Policy Liberality (5-year MA)"),
          add.lines = list(c("Origin FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$"),
                           c("Dest. FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$"),
                           c("Year FE", "$\\textrm{X}$", "$\\checkmark$", "$\\checkmark$")))


sk_dat <- fread("sk_dat.csv")

m5 <- lfe::felm(log_count ~ bo +
                  ihs_stock + 
                  ihs(gdp_ratio) +
                  gdp_ratio2 +
                  comlang_off +
                  col45 + 
                  log(distw) +
                  lib_dem_o +
                  lib_dem +
                  ihs(pop_o) +
                  ihs(pop_d) +
                  nAC +
                  nCIV_o +
                  nINT + 
                  nINT_o |
                  iso3_o + iso3_d + year | 0 | dyad, data = sk_dat)

m6 <- lfe::felm(log_count ~ bo + liberal_5yma +
                  ihs_stock + 
                  ihs(gdp_ratio) +
                  gdp_ratio2 +
                  comlang_off +
                  col45 + 
                  log(distw) +
                  lib_dem_o +
                  lib_dem +
                  ihs(pop_o) +
                  ihs(pop_d) +
                  nAC +
                  nCIV_o +
                  nINT + 
                  nINT_o |
                  iso3_o + iso3_d + year | 0 | dyad, data = sk_dat)

m7 <- lfe::felm(log_count ~ bo * liberal_5yma +
                  ihs_stock + 
                  ihs(gdp_ratio) +
                  gdp_ratio2 +
                  comlang_off +
                  col45 + 
                  log(distw) +
                  lib_dem_o +
                  lib_dem +
                  ihs(pop_o) +
                  ihs(pop_d) +
                  nAC +
                  nCIV_o +
                  nINT + 
                  nINT_o |
                  iso3_o + iso3_d + year | 0 | dyad, data = sk_dat)

# table D.VII
stargazer(m5, m6, m7, type = "latex",
          omit = c("factor", "time_trend"),
          align = TRUE,
          star.cutoffs = c(.1, .05, .01),
          star.char = c("†", "*", "**"),
          dep.var.labels = "IHS Refugee Flow",
          covariate.labels = c("Border Orientation", 
                               "DEMIG Policy Liberality (5-year MA)",
                               "IHS Migrant Stock",
                               "IHS GDPc Ratio",
                               "IHS GDPc Ratio (sq)",
                               "Common Language",
                               "Colonial Tie",
                               "IHS Distance",
                               "Lib. Democracy Origin",
                               "Lib. Democracy Dest.",
                               "IHS Population Origin",
                               "IHS Population Dest.",
                               "Near Violence Dest.",
                               "Civil War Origin",
                               "International War Dest.",
                               "International War Origin.",
                               "Fence X DEMIG Policy Liberality (5-year MA)"),
          add.lines = list(c("Origin FE", "$\\checkmark$","$\\checkmark$"),
                           c("Dest. FE", "$\\checkmark$","$\\checkmark$"),
                           c("Year FE", "$\\textrm{X}$","$\\checkmark$")))