library(lfe)
library(xtable)
library(data.table)
library(bayestestR)
library(countrycode)
library(staggered)
library(gsynth)

treat_dat <- fread("analysis_dat.csv")

################
# appx A
################
m1 <- lfe::felm(log_count_pop ~ fenced + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu |
                  stateA + year | 0 | state_id + year, data = treat_dat)
dat <- data.table(state = m1$fe$stateA, year = as.numeric(levels(m1$fe$year)[m1$fe$year]))
tab <- dat[, .(From = min(year), To = max(year)), by = state][order(state)]
print.xtable(xtable(tab[1:52], digits = 0), booktabs = TRUE, include.rownames = FALSE)
print.xtable(xtable(tab[53:104], digits = 0), booktabs = TRUE, include.rownames = FALSE)
print.xtable(xtable(tab[105:156], digits = 0), booktabs = TRUE, include.rownames = FALSE)

################
# Appx B
################
m1_north <- lfe::felm(log_count_pop ~ fenced + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem + eu |
                        state_id + year | 0 | state_id + year, data = treat_dat[north == 1])
m1_south <- lfe::felm(log_count_pop ~ fenced + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem |
                        state_id + year | 0 | state_id + year, data = treat_dat[north == 0])

m2_north <- lfe::felm(log_count_pop ~ fenced + 
                        lag_count_pop + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem + 
                        eu|
                        state_id + year | 0 | state_id + year, data = treat_dat[north == 1])

m2_south <- lfe::felm(log_count_pop ~ fenced + 
                        lag_count_pop + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem |
                        state_id + year | 0 | state_id + year, data = treat_dat[north == 0])

m3_north <- lfe::felm(log_count_pop ~ fenced + 
                        lag_count_pop + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem + 
                        eu + time_trend * factor(state_id) |
                        state_id + year | 0 | state_id + year, data = treat_dat[north == 1])

m3_south <- lfe::felm(log_count_pop ~ fenced + 
                        lag_count_pop + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem + 
                        time_trend * factor(state_id)|
                        state_id + year | 0 | state_id + year, data = treat_dat[north == 0])

m4_north <- lfe::felm(log_count_pop ~ fenced + 
                        lag_count_pop + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem + 
                        eu + time_trend * factor(state_id) |
                        state_id | 0 | state_id + year, data = treat_dat[north == 1])

m4_south <- lfe::felm(log_count_pop ~ fenced + 
                        lag_count_pop + 
                        log_gdpcap +
                        gdp_shock + 
                        lag_gdp_shock +
                        near_conflict + 
                        int_conflict + 
                        lib_dem + 
                        time_trend * factor(state_id)|
                        state_id | 0 | state_id + year, data = treat_dat[north == 0])


stargazer(m1_north, m2_north, m3_north, m4_north, type = "latex",
          omit = c("factor", "time_trend"),
          align = TRUE,
          star.cutoffs = c(.1, .05, .01),
          star.char = c("†", "*", "**"),
          dep.var.labels = "IHS Refugee Flow",
          covariate.labels = c("Border Fence", 
                               "Lag IHS Refugees",
                               "Log GDPc",
                               "Negative GDP Shock",
                               "GDP Shock (t-1)", 
                               "Nearby Conflict",
                               "International Conflict",
                               "Liberal Democracy",
                               "EU Member"),
          add.lines = list(c("Country FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$"),
                           c("Year FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\textrm{X}$"),
                           c("Country Time Trend", "$\\textrm{X}$", "$\\textrm{X}$", "$\\checkmark$", "$\\checkmark$")))

stargazer(m1_south, m2_south, m3_south, m4_south, type = "latex",
          omit = c("factor", "time_trend"),
          align = TRUE,
          star.cutoffs = c(.1, .05, .01),
          star.char = c("†", "*", "**"),
          dep.var.labels = "IHS Refugee Flow",
          covariate.labels = c("Border Fence", 
                               "Lag IHS Refugees",
                               "Log GDPc",
                               "Negative GDP Shock",
                               "GDP Shock (t-1)", 
                               "Nearby Conflict",
                               "International Conflict",
                               "Liberal Democracy"),
          add.lines = list(c("Country FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$"),
                           c("Year FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\textrm{X}$"),
                           c("Country Time Trend", "$\\textrm{X}$", "$\\textrm{X}$", "$\\checkmark$", "$\\checkmark$")))


################
# Appx C
################
treat_dat[, arrive_shock_thresh := quantile(log_count_pop, probs = 0.75, na.rm = TRUE), by = year]
treat_dat[, log_count_pop_shock := ifelse(log_count_pop >= arrive_shock_thresh, 1, 0)]
treat_dat[, lag_count_shock := shift(log_count_pop_shock), by = stateA]
m1 <- lfe::felm(log_count_pop_shock ~ fenced + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + eu |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m2 <- lfe::felm(log_count_pop_shock ~ fenced + 
                  lag_count_shock + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m3 <- lfe::felm(log_count_pop_shock ~ fenced + 
                  lag_count_shock + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu + time_trend * factor(state_id) |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m4 <- lfe::felm(log_count_pop_shock ~ fenced + 
                  lag_count_shock + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu + time_trend * factor(state_id) |
                  state_id | 0 | state_id + year, data = treat_dat)

stargazer(m1, m2, m3, m4, type = "latex",
          omit = c("factor", "time_trend"),
          align = TRUE,
          star.cutoffs = c(.1, .05, .01),
          star.char = c("†", "*", "**"),
          dep.var.labels = "Refugee Shock",
          covariate.labels = c("Border Fence", 
                               "Lag Refugee Shock",
                               "Log GDPc",
                               "Negative GDP Shock",
                               "GDP Shock (t-1)", 
                               "Nearby Conflict",
                               "International Conflict",
                               "Liberal Democracy",
                               "EU Member"),
          add.lines = list(c("Country FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$"),
                           c("Year FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\textrm{X}$"),
                           c("Country Time Trend", "$\\textrm{X}$", "$\\textrm{X}$", "$\\checkmark$", "$\\checkmark$")))


#######################
# Appx E: Leave-one-out
#######################
res <- lapply(unique(treat_dat$stateA), function(i){
  m1 <- lfe::felm(log_count_pop ~ fenced + 
                    log_gdpcap +
                    gdp_shock + 
                    lag_gdp_shock +
                    near_conflict + 
                    int_conflict + 
                    lib_dem + 
                    eu |
                    stateA + year | 0 | state_id + year, 
                  data = treat_dat[stateA != i])
  c("Est" = coef(m1)[1], 
    "Low" = coef(m1)[1] - (2 * vcov(m1)[1, 1]),
    "High" = coef(m1)[1] + (2 * vcov(m1)[1, 1]))
})
res_dat <- data.table(do.call(rbind, res))
colnames(res_dat) <- c("Est", "Low", "High")
res_dat$mod <- 1:nrow(res_dat)

png("figE3.png", res = 300, 
    width = 10, height = 6, units = "in")
ggplot(res_dat, aes(mod, Est)) +
  geom_point() +
  geom_pointrange(aes(ymin = Low, ymax = High)) +
  theme_bw() +
  xlab("") +
  ylab("Estimated Effect of Fences") +
  theme(axis.text.x = element_blank()) +
  annotate("text", x = 20, y = 0.2653809, label = "Model without Botswana", size = 4) +
  ggtitle("Leave-one-out Replication of Model (1)")
dev.off()



#######################
# Appx E: Random Slopes
#######################
treat_dat[, region := countrycode(stateA, "country.name", "region")]
m1 <- lmer(log_count ~ fenced + (1 + fenced | region) +
             log_gdpcap +
             gdp_shock + 
             lag_gdp_shock +
             near_conflict + 
             int_conflict + 
             lib_dem + 
             eu + 
             log_pop + (1 | year), data = treat_dat)
north <- c("Austria", "Belgium", "Bulgaria", "Cyprus", 
           "Denmark", "Finland", "France", "Germany", "Greece", "Hungary", 
           "Ireland", "Italy", "Liechtenstein", "Malta",
           "Japan", "Luxembourg", "Netherlands", "New Zealand", "Norway",
           "Poland", "Portugal", "Romania", "Spain", "Sweden", 
           "Switzerland", "United Kingdom", "United States", "Turkey", 
           "Estonia", "Latvia", "Lithuania", "Armenia", 
           "Moldova, Republic of", "Croatia", "Slovenia", 
           "Bosnia and Herzegovina", "Czech Republic", "Slovakia", 
           "Macedonia, the former Yugoslav Republic of", "Serbia", "Montenegro")
sims <- sim(m1)

pars <- paste("fenced", unique(treat_dat$stateA[!(treat_dat$stateA %in% north)]), sep=".")
x <- ci(sims, ci = c(.95), effects = "random", parameters = pars, method = "CI")

m1 <- lmer(log_count ~ fenced + (1 + fenced | stateA) +
             log_gdpcap +
             gdp_shock + 
             lag_gdp_shock +
             near_conflict + 
             int_conflict + 
             lib_dem + 
             eu + log_pop + (1 | year), data = treat_dat)
sims <- sim(m1)


fun <- function(region){
  pars <- paste("fenced", 
                unique(treat_dat$stateA[treat_dat$region %in% region & treat_dat$stateA != "West Germany"]), sep=".")
  x <- ci(sims, ci = c(.95), effects = "random", parameters = pars, method = "HDI")
  p <- plot(x)
  p$data$y <- gsub("fenced\\.", "", p$data$y)
  p + 
    ggtitle(region) +
    xlab("") +
    ylab("") +
    theme_bw()
}

res <- lapply(unique(treat_dat$region), fun)
p1 <- plot_grid(res[[1]], res[[2]], res[[3]], res[[4]], res[[5]], res[[6]], res[[7]],
                ncol = 2)

png("figE2.png", width = 12, height = 20, units = "in", res = 300)
p1
dev.off()

###############################
# Appendix F
###############################
att_test <- PanelMatch(lag = 4, time.id = "year", unit.id = "state_id", 
                       treatment = "fenced", refinement.method = "mahalanobis", 
                       data = treat_dat, match.missing = TRUE, 
                       listwise.delete = FALSE,
                       covs.formula = ~ eu +
                         I(lag(log_count, 1)) + 
                         log_gdpcap +
                         gdp_shock + 
                         log_pop +
                         lib_dem +
                         near_conflict +
                         int_conflict, 
                       size.match = 5, qoi = "att" ,outcome.var = "log_count_pop",
                       lead = 0:10, forbid.treatment.reversal = FALSE,
                       use.diagonal.variance.matrix = TRUE)
balance <- get_covariate_balance(att_test$att,
                                 data = treat_dat,
                                 covariates = c("log_gdpcap", "near_conflict",
                                                "log_count", "log_pop", "int_conflict",
                                                "lib_dem",
                                                "eu"), 
                                 plot = FALSE, # visualize by setting plot to TRUE
                                 ylim = c(-.2, .2))
colnames(balance) <- c("GDPc", "Nearby Conflict", "Lag Refugees", "Pop.", "Int. Conflict",
                       "Lib. Democracy",  "EU")
balance <- melt(as.data.table(balance))
balance[, time := rep(c("t-4", "t-3", "t-2", "t-1", "t"), times = 7)]

bt <- ggplot(balance, aes(time, value, group = variable)) +
  geom_line(aes(linetype = variable)) +
  theme_minimal() +
  geom_hline(yintercept = 0.3, lwd = 2) +
  geom_hline(yintercept = -0.3, lwd = 2) +
  labs(title = "Balance Test Plot",
       subtitle = "Balancing refinement: mahalanobis distance matching") +
  ylab("") +
  xlab("") +
  theme(legend.title=element_blank())

png("figF4.png", res = 300, 
    width = 6, height = 4, units = "in")
bt
dev.off()


#######################################
# Appx G: generalized synthetic control
#######################################
m2a <- lm(log_count_pop ~ fenced + lag_log_count + 
            log_gdpcap +
            gdp_shock + 
            lag_gdp_shock +
            near_conflict + 
            int_conflict + 
            lib_dem + 
            eu + factor(state_id) + time_trend, data = treat_dat)
dat <- m2a$model
out <- gsynth(log_count_pop ~ fenced + lag_log_count +
                log_gdpcap +
                gdp_shock + 
                lag_gdp_shock +
                near_conflict + 
                int_conflict + 
                lib_dem, data = dat, parallel = TRUE, cores = 3,
              index = c("factor(state_id)","time_trend"), force = "two-way",
              CV = TRUE, r = c(0, 5), se = TRUE,
              min.T0 = 7, 
              inference = "parametric")
png("figH5.png", res = 300, 
    width = 6, height = 4, units = "in")
plot(out, type = "counterfactual", raw = "none", main="Effect of Fences", 
     ylab = "Refugee Arrivals") +
  labs(subtitle = "ATT: -0.058, 95% CI: (-1.215, 1.097)") +
  xlim(c(-15, 15)) +
  theme(plot.subtitle = element_text(hjust = 0.5))

#########################
# Appx G: sun and abraham
#########################
setDT(treat_dat)
treat_dat2 <- merge(treat_dat, treat_dat[sum(fenced) > 0 & fenced == 1, 
                                         .(g = min(time_trend)), by = stateA], 
                    by = "stateA", all.x = TRUE)
treat_dat2[, g := ifelse(is.na(g), 0, g)]
df <- treat_dat2[, .(t = time_trend, i = state_id, g = g, y = log_count_pop)]
full_panel <- expand.grid("i" = 1:168, "t" = 1:48)
full_dat <- merge(df, full_panel, all.y = TRUE, by = c("i", "t"))
full_dat[, g := min(g, na.rm = TRUE), by = i]
full_dat[, avg_value := mean(y, na.rm = TRUE), by = i]
full_dat[, y := ifelse(is.na(y), avg_value, y)]
staggered_sa(df = full_dat, estimand = "cohort")
dev.off()