library(readstata13)
library(ggplot2)
library(data.table)
library(stargazer)
library(lme4)
library(arm)
library(countrycode)
library(PanelMatch)
library(vdem)
library(wbstats)
library(xtable)
library(ggpubr)
library(stringr)
ihs <- function(x) {
  y <- log(x + sqrt(x ^ 2 + 1))
  return(y)
}
hs <- function(x) {
  y <- 0.5*exp(-x)*(exp(2*x)-1)
  return(y)
}


################
# Table 1
################
treat_dat <- fread("analysis_dat.csv")

m1 <- lfe::felm(log_count_pop ~ fenced + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m2 <- lfe::felm(log_count_pop ~ fenced + 
                  lag_count_pop + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                 eu |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m3 <- lfe::felm(log_count_pop ~ fenced + 
                  lag_count_pop + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu + time_trend * factor(state_id) |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m4 <- lfe::felm(log_count_pop ~ fenced + 
                  lag_count_pop + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu + time_trend * factor(state_id) |
                  state_id | 0 | state_id + year, data = treat_dat)


stargazer(m1, m2, m3, m4, type = "latex",
          omit = c("factor", "time_trend"),
          align = TRUE,
          star.cutoffs = c(.1, .05, .01),
          star.char = c("†", "*", "**"),
          dep.var.labels = "IHS Refugee Flow",
          covariate.labels = c("Border Fence", 
                               "Lag IHS Refugees",
                               "Log GDPc",
                               "Negative GDP Shock",
                               "GDP Shock (t-1)", 
                               "Nearby Conflict",
                               "International Conflict",
                               "Liberal Democracy",
                               "EU Member"),
          add.lines = list(c("Country FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$"),
                           c("Year FE", "$\\checkmark$", "$\\checkmark$", "$\\checkmark$", "$\\textrm{X}$"),
                           c("Country Time Trend", "$\\textrm{X}$", "$\\textrm{X}$", "$\\checkmark$", "$\\checkmark$")))






#############
# Figure 1
#############
m1 <- lfe::felm(log_count_pop ~ fenced + 
                  lag_count_pop +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu |
                  stateA + year | 0 | state_id + year, data = treat_dat)
m2 <- lfe::felm(log_count_pop ~ fenced + 
                  lag_count_pop + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m3 <- lfe::felm(log_count_pop ~ fenced + 
                  lag_count_pop + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu + time_trend * factor(state_id) |
                  state_id + year | 0 | state_id + year, data = treat_dat)

m4 <- lfe::felm(log_count_pop ~ fenced + 
                  lag_count_pop + 
                  log_gdpcap +
                  gdp_shock + 
                  lag_gdp_shock +
                  near_conflict + 
                  int_conflict + 
                  lib_dem + 
                  eu + time_trend * factor(state_id) |
                  state_id | 0 | state_id + year, data = treat_dat)

high <- c(coef(m1)[1] + 1.64 * m1$cse[1], coef(m2)[1] + 1.64 * m2$cse[1],
          coef(m3)[1] + 1.64 * m3$cse[1], coef(m4)[1] + 1.64 * m4$cse[1])
low <- c(coef(m1)[1] - 1.64 * m1$cse[1], coef(m2)[1] - 1.64 * m2$cse[1],
          coef(m3)[1] - 1.64 * m3$cse[1], coef(m4)[1] - 1.64 * m4$cse[1])

ggdat <- data.table(low = low,
                    high = high,
                    est = c(coef(m1)[1],  coef(m2)[1], coef(m3)[1], coef(m4)[1]),
                    mod = c("Model 1",  "Model 2", "Model 3", "Model 4"),
                    ci = "ROPE")

png("fig1.png", res = 300, 
    width = 10, height = 6, units = "in")
ggplot(ggdat, aes(est, mod, group = mod)) +
  geom_point() +
  geom_pointrange(aes(xmin = low, xmax = high)) +
  xlim(c(-1.5, 1.5)) +
  geom_vline(xintercept = 0.28, linetype = "dashed") +
  geom_vline(xintercept = -0.28, linetype = "dashed") +
  theme_bw() +
  xlab("Estimated Effect of Border Fence on Refugees") +
  ylab("") +
  theme(text = element_text(size=20)) +
  labs(title = "Equivalence Test for Table 1")
dev.off()



################
# Figure 2
################
setDF(treat_dat)
att_test <- PanelMatch(lag = 4, time.id = "year", unit.id = "state_id", 
                       treatment = "fenced", refinement.method = "mahalanobis", 
                       data = treat_dat, match.missing = TRUE, 
                       listwise.delete = FALSE,
                       covs.formula = ~ eu +
                         I(lag(log_count, 1)) + 
                         log_gdpcap +
                         gdp_shock + 
                         log_pop +
                         lib_dem +
                         near_conflict +
                         int_conflict, 
                       size.match = 5, qoi = "att" ,outcome.var = "log_count_pop",
                       lead = 0:10, forbid.treatment.reversal = FALSE,
                       use.diagonal.variance.matrix = TRUE)


png("fig2.png", res = 300, 
    width = 10, height = 6, units = "in")
plot(PanelEstimate(sets = att_test, data = treat_dat), 
     main = "ATT of Border Fences on Log Refugee Flows, Lag = 4", 
     cex.lab=1.5, cex.axis = 1.5, cex.main = 1.5)
dev.off()



